import React, { ReactEventHandler } from 'react';

interface InputProps {
  id: string;
  name?: string;
  label: React.ReactNode;
  classNames?: string[];
  value?: string | undefined;
  required?: boolean;
  type?: string;
  disabled?: boolean;
  onChange?: undefined | ReactEventHandler;
}
export const Input: React.FC<InputProps> = ({
  id,
  label,
  classNames = [],
  type = 'text',
  required,
  onChange = undefined,
  ...args
}: InputProps) => {
  classNames = ['field', ...classNames];
  if (required) classNames.push('mandatory');

  const attributes = { id, type, onChange, required, ...args };

  return (
    <div className={classNames.join(' ')}>
      <label htmlFor={id}>{label}</label>
      {type == 'textarea' ? (
        <textarea {...attributes}></textarea>
      ) : (
        <input {...attributes} />
      )}
    </div>
  );
};
export default Input;
