import * as React from 'react';
import { screen, render } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import LocaleSwitcher from './LocaleSwitcher';
import i18next, { Resource } from 'i18next';
import { initReactI18next } from 'react-i18next';

jest.unmock('react-i18next');

const mockResources: Resource = {
  en: {
    translation: {
      language: "English",
    }

  },
  bc: {
    translation: {
      language: "Belter Creole"
    }
  }
}
// initReactI18next is not mocked, it's passed throught the mock untouched.
i18next.use(initReactI18next).init({ 
  resources: mockResources,
  lng: 'en',
  interpolation: {
    escapeValue: false,
  },
});

describe('<LocaleSwitcher>', () => {
  it('renders a list of languages', () => {
    render(<LocaleSwitcher />);
    const elSelect = screen.getByRole('combobox');
    expect(elSelect).toHaveValue('en');
    userEvent.selectOptions(elSelect, ['bc']);
    expect(elSelect).toHaveValue('bc');
  });
});
